@@ -83,16 +83,22 @@ def stackdriver_sink(message, project):
     print(serialized, file=sys.stderr)
 
 
+DEFAULT_ZIPKIN_ENDPOINT = os.environ.get(
+    "ZIPKIN_ENDPOINT",
+    "http://zipkin-gcp.observability.svc.cluster.local:9411/api/v2/spans",
+)
+
+
 def setup_logging_fastapi_gcp(
-    app: FastAPI, *, enable_tracing=True, GCP_PROJECT="databutton"
+    app: FastAPI, *, zipkin_endpoint=DEFAULT_ZIPKIN_ENDPOINT, GCP_PROJECT="databutton"
 ):
     """
     Sets up logging and tracing for FastAPI based projects.
     """
     app.add_middleware(BaseHTTPMiddleware, dispatch=http_request_middleware_func)
     app.add_middleware(CorrelationIdMiddleware)
-    if enable_tracing:
-        add_traces_to_fastapi(app)
+    if zipkin_endpoint is not None:
+        add_traces_to_fastapi(app, zipkin_endpoint=zipkin_endpoint)
 
     loggers = (
         logging.getLogger(name)
